aboutsummaryrefslogtreecommitdiffstats
path: root/epan/packet.h
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2017-04-16 18:48:30 -0700
committerGuy Harris <guy@alum.mit.edu>2017-04-17 01:49:01 +0000
commit407a2b07e55a262905881c7d1e225d618e9824fb (patch)
treeff273d3ca4dc747c9dc397244a04d90872c3b4d0 /epan/packet.h
parent1bfc8580e322450f8afaaf797e236469b948c984 (diff)
Rename some routines and structure members.
They deal with sets of hfids, which can belong to protocols as well as fields (I guess you could argue that a protocol is a field, but...). Change-Id: Ibd103cfa26427ead4ef54be89f1251908004cfae Reviewed-on: https://code.wireshark.org/review/21154 Reviewed-by: Guy Harris <guy@alum.mit.edu>
Diffstat (limited to 'epan/packet.h')
-rw-r--r--epan/packet.h15
1 files changed, 8 insertions, 7 deletions
diff --git a/epan/packet.h b/epan/packet.h
index e0625ae226..d6e512532f 100644
--- a/epan/packet.h
+++ b/epan/packet.h
@@ -776,11 +776,11 @@ WS_DLL_PUBLIC void dissector_dump_heur_decodes(void);
WS_DLL_PUBLIC void register_postdissector(dissector_handle_t handle);
/*
* Specify a set of fields that the postdissector will need.
* The GArray is an array of hfids.
*/
-WS_DLL_PUBLIC void set_postdissector_wanted_fields(dissector_handle_t handle,
- GArray *wanted_fields);
+WS_DLL_PUBLIC void set_postdissector_wanted_hfids(dissector_handle_t handle,
+ GArray *wanted_hfids);
/*
* Deregister a postdissector. Not for use in (post)dissectors or
@@ -803,15 +803,16 @@ extern gboolean have_postdissector(void);
extern void call_all_postdissectors(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree);
/*
- * Return TRUE if at least one postdissector wants fields, FALSE otherwise.
+ * Return TRUE if at least one postdissector needs at least one hfid,
+ * FALSE otherwise.
*/
-WS_DLL_PUBLIC gboolean postdissectors_want_fields(void);
+WS_DLL_PUBLIC gboolean postdissectors_want_hfids(void);
/*
* Prime an epan_dissect_t with all the fields wanted by postdissectors.
*/
WS_DLL_PUBLIC void
-prime_epan_dissect_with_postdissector_wanted_fields(epan_dissect_t *edt);
+prime_epan_dissect_with_postdissector_wanted_hfids(epan_dissect_t *edt);
/** @} */
@@ -776,11 +776,11 @@ WS_DLL_PUBLIC void dissector_dump_heur_decodes(void);
WS_DLL_PUBLIC void register_postdissector(dissector_handle_t handle);
/*
- * Specify a set of fields that the postdissector will need.
+ * Specify a set of hfids that the postdissector will need.
* The GArray is an array of hfids.
*/
@@ -803,15 +803,16 @@ extern gboolean have_postdissector(void);
/*
- * Prime an epan_dissect_t with all the fields wanted by postdissectors.
+ * Prime an epan_dissect_t with all the hfids wanted by postdissectors.
*/
WS_DLL_PUBLIC void